@@ -6,7 +6,7 @@ use warnings;
 use Crypt::Password 0.23 ();
 use Data::SimplePassword;
 
-use base 'Nitesi::Object::Singleton';
+use Moo;
 
 =head1 NAME
 
@@ -88,7 +88,7 @@ Stefan Hornburg (Racke), <racke@linuxia.de>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011-2012 Stefan Hornburg (Racke) <racke@linuxia.de>.
+Copyright 2011-2013 Stefan Hornburg (Racke) <racke@linuxia.de>.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
